@@ -1,6 +1,8 @@
 
 from .perf import timing
+from . import debug
 
 
 __all__ = (
+    "debug",
     "timing", )
